@@ -1,6 +1,7 @@
 # Author: Babak Naimi, naimi.b@gmail.com
 # Date :  August 2017
-# Version 1.1
+# Last Update :  October 2021
+# Version 1.2
 # Licence GPL v3
 #---------------
 
@@ -23,6 +24,15 @@ setClass("RasterBrickTS",
          )
 
 
+setClass("SpatRasterTS",
+         representation(raster="SpatRaster",
+                        time="xts"),
+         validity=function(object){
+           return (nlyr(object@raster) == length(object@time))
+         }  
+)
+
+
 setClassUnion("RasterStackBrickTS", c("RasterStackTS", "RasterBrickTS"))
 
 
